==============
totango-python
==============


Totango (http://www.totango.com) Python Library

* Free software: Apache License, Version 2.0


Installation
============

::

    pip install totango


Usage
=====

::

    import totango

    tt = totango.Totango('SP-XXXX-XX', 'user_id')
    tt.track('module','action')
